/*
 * vzct_utils.h: core driver functions for managing
 * Virtuozzo Containers
 *
 * Copyright (C) 2017 Virtuozzo, Inc.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; If not, see
 * <http://www.gnu.org/licenses/>.
 *
 */

#ifndef VZCT_UTILS_H
# define VZCT_UTILS_H

# include <vzctl/libvzctl.h>

# include "driver.h"
# include "conf/domain_conf.h"
# include "conf/snapshot_conf.h"
# include "conf/virdomainobjlist.h"
# include "conf/domain_event.h"
# include "virthread.h"
# include "datatypes.h"
#include "virclosecallbacks.h"
#include "virportallocator.h"
#include "virthreadpool.h"

struct _vzctDriverConfig {
    virObject parent;

    char *configDir;
    char *saveDir;
    char *autostartDir;
    char *stateDir;
    char *snapshotDir;
};
typedef struct _vzctDriverConfig vzctDriverConfig;
typedef vzctDriverConfig *vzctDriverConfigPtr;

struct _vzctDriver {
    virMutex lock;

    /* Immutable pointer, self-locking APIs */
    virDomainObjListPtr domains;
    virCapsPtr caps;
    vzctDriverConfigPtr config;
    virDomainXMLOptionPtr xmlopt;
    virObjectEventStatePtr domainEventState;
    virSysinfoDefPtr hostsysinfo;
    virCloseCallbacksPtr closeCallbacks;
    /* immutable, self-locking */
    virPortAllocatorRangePtr vncPorts;
    virPortAllocatorRangePtr migrationPorts;
    int lastvmid;
    virThreadPoolPtr workerPool;

    int eventfd;
    int eventmon;

};
typedef struct _vzctDriver vzctDriver;
typedef struct _vzctDriver *vzctDriverPtr;

struct _vzctDomainObjPrivate {
    bool created;
    pid_t vncPid;
    pid_t migrationPid;
    int migrationPort;

    virCond jobCond;
    bool job;
    bool jobAborted;
    unsigned long long jobStarted;
    bool migration;
};

typedef struct _vzctDomainObjPrivate vzctDomainObjPrivate;
typedef vzctDomainObjPrivate *vzctDomainObjPrivatePtr;

static inline void vzctDriverLock(vzctDriverPtr driver)
{
        virMutexLock(&driver->lock);
}
static inline void vzctDriverUnlock(vzctDriverPtr driver)
{
        virMutexUnlock(&driver->lock);
}

#endif /* VZCT_UTILS_H */
