/*
 * vzct_vzctl.h: core driver functions for managing
 * Virtuozzo Containers
 *
 * Copyright (C) 2017 Virtuozzo, Inc.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; If not, see
 * <http://www.gnu.org/licenses/>.
 *
 */

#ifndef VZCT_VZCTL_H
# define VZCT_VZCTL_H

int vzctlDomainCreate(virDomainObjPtr dom, bool paused, char *dumppath);
int vzctlDomainDestroy(virDomainObjPtr dom, stop_mode_e stop_mode);
int vzctlDomainReset(virDomainObjPtr dom);
int vzctlDomainPause(virDomainObjPtr dom);
int vzctlDomainUnpause(virDomainObjPtr dom);
int vzctlDomainRestart(virDomainObjPtr dom);
int vzctlDomainSuspend(virDomainObjPtr dom, const char *dumppath);
bool vzctlDomainActive(virDomainObjPtr dom);
int vzctlDomainVCPUStats(virDomainObjPtr dom, unsigned long long *ns);

/* size in KiB */
int vzctlDomainDiskResize(virDomainObjPtr dom,
                          const char *path,
                          unsigned long long size);

int vzctlDomainBlockStats(virDomainObjPtr dom,
                          const char *path,
                          virDomainBlockStatsPtr stats);

int vzctlDomainBlockStatsAll(virDomainObjPtr dom,
                             virDomainBlockStatsPtr stats);

int vzctlDomainMemoryStats(virDomainObjPtr dom,
                           virDomainMemoryStatPtr stats,
                           unsigned int nr_stats);

int vzctlDomainSetUserPassword(virDomainObjPtr dom,
                               const char *user,
                               const char *password,
                               unsigned int flags);

virDomainSnapshotObjListPtr vzctlLoadSnapshots(virDomainObjPtr dom);

int vzctlAttachDisk(virDomainObjPtr dom, virDomainDeviceDefPtr disk);
int vzctlDetachDisk(virDomainObjPtr dom, virDomainDeviceDefPtr disk);
int vzctlAttachNet(virDomainObjPtr dom, virDomainNetDefPtr net);
int vzctlDetachNet(virDomainObjPtr dom, virDomainNetDefPtr net);
int vzctlSetVcpus(virDomainObjPtr dom, unsigned int nvcpus);
int vzctlSetMemory(virDomainObjPtr dom, unsigned long newmem);
int vzctlCreateSnapshot(virDomainObjPtr dom, virDomainSnapshotObjPtr snap);
int vzctlRevertSnapshot(virDomainObjPtr dom, virDomainSnapshotObjPtr snap);
int vzctlDeleteSnapshot(virDomainObjPtr dom, virDomainSnapshotObjPtr snap);

int vzctlMigrationStartServer(vzctDriverPtr driver,
                              virDomainObjPtr dom,
                              int nmigrate_disks,
                              const char **migrate_disks,
                              bool copy);

int vzctlMigrationStartClient(virDomainObjPtr dom,
                              const char *uristr,
                              int port,
                              int nmigrate_disks,
                              const char **migrate_disks,
                              bool copy,
                              bool live);

void vzctlMigrationStopServer(vzctDriverPtr driver, virDomainObjPtr dom);


#endif /* VZCT_VZCTL_H */
